@@ -1,15 +1,15 @@
 package Text::Hspell;
-
+$Text::Hspell::VERSION = '0.2.3';
+use 5.014;
 use strict;
 use warnings;
 
 require DynaLoader;
 
+use vars qw/ $VERSION /;
 use vars qw(@ISA);
 @ISA = qw/ DynaLoader /;
 
-our $VERSION = '0.2.2';
-
 bootstrap Text::Hspell $VERSION;
 
 use Encode qw/ encode /;
@@ -39,7 +39,7 @@ Text::Hspell - wrapper for the hspell (= Hebrew speller) library
 
 =head1 VERSION
 
-version 0.2.2
+version 0.2.3
 
 =head1 SYNOPSIS
 
@@ -136,14 +136,6 @@ L<https://metacpan.org/release/Text-Hspell>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Text-Hspell>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -152,14 +144,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Hspell>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Text-Hspell>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
